==> qupzilla_1.6.6.orig.tar.xz: qupzilla-1.6.6.orig/src/lib/app/mainapplication.h <==
/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2010-2013  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef MAINAPPLICATION_H
#define MAINAPPLICATION_H

#define mApp MainApplication::getInstance()

#include <QList>
#include <QUrl>
#include <QPointer>

#include "restoremanager.h"
#include "qtsingleapplication.h"
#include "qz_namespace.h"

class QMenu;
class QWebSettings;
class QNetworkDiskCache;

class QupZilla;
class CookieManager;
class BrowsingLibrary;
class History;
class NetworkManager;
class CookieJar;
class RSSManager;
class Updater;
class PluginProxy;
class BookmarksModel;
class DownloadManager;
class AutoFill;
class DesktopNotificationsFactory;
class IconProvider;
class SearchEnginesManager;
class DatabaseWriter;
class UserAgentManager;
class ProxyStyle;
class RegisterQAppAssociation;
class HTML5PermissionsManager;
class Speller;

#ifdef Q_OS_MAC
class MacMenuReceiver;
#endif

class QT_QUPZILLA_EXPORT MainApplication : public QtSingleApplication
{
    Q_OBJECT

public:
    QString DATADIR;
    QString PROFILEDIR;
    QString TRANSLATIONSDIR;
    QString THEMESDIR;

    explicit MainApplication(int &argc, char** argv);
    ~MainApplication();

    void connectDatabase();
    void reloadSettings();
    bool restoreStateSlot(QupZilla* window, RestoreData recoveryData);
    QupZilla* makeNewWindow(Qz::BrowserWindow type, const QUrl &startUrl = QUrl());
    void aboutToCloseWindow(QupZilla* window);
    bool isStateChanged();

    QList<QupZilla*> mainWindows();

    static MainApplication* getInstance() { return static_cast<MainApplication*>(QCoreApplication::instance()); }

    bool isClosing() const;
    bool isRestoring() const;
    bool isPrivateSession() const;
    bool isPortable() const;
    bool isStartingAfterCrash() const;
    int windowCount() const;
    QString currentLanguageFile() const;
    QString currentLanguage() const;
    QString currentProfilePath() const;

    bool checkSettingsDir();
    void destroyRestoreManager();
    void clearTempPath();

    ProxyStyle* proxyStyle() const;
    void setProxyStyle(ProxyStyle* style);

    QString currentStyle() const;
    QString tempPath() const;

    QupZilla* getWindow();
    CookieManager* cookieManager();
    BrowsingLibrary* browsingLibrary();
    History* history();
    QWebSettings* webSettings();
    NetworkManager* networkManager();
    CookieJar* cookieJar();
    RSSManager* rssManager();
    PluginProxy* plugins();
    BookmarksModel* bookmarksModel();
    DownloadManager* downManager();
    AutoFill* autoFill();
    SearchEnginesManager* searchEnginesManager();
    QNetworkDiskCache* networkCache();
    DesktopNotificationsFactory* desktopNotifications();
    HTML5PermissionsManager* html5permissions();
#ifdef USE_HUNSPELL
    Speller* speller();
#endif

    DatabaseWriter* dbWriter() { return m_dbWriter; }
    UserAgentManager* uaManager() { return m_uaManager; }
    RestoreManager* restoreManager() { return m_restoreManager; }

#if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
    RegisterQAppAssociation* associationManager();
#endif

#ifdef Q_OS_MAC
    MacMenuReceiver* macMenuReceiver();
    QMenu* macDockMenu();
    bool event(QEvent* e);
#endif

public slots:
    bool saveStateSlot();
    void quitApplication();
    void sendMessages(Qz::AppMessageType mes, bool state);
    void receiveAppMessage(QString message);
    void setStateChanged();
    void addNewTab(const QUrl &url = QUrl());

    void startPrivateBrowsing();
    void reloadUserStyleSheet();
    bool checkDefaultWebBrowser();

signals:
    void message(Qz::AppMessageType mes, bool state);

private slots:
    void loadSettings();
    void postLaunch();
    void setupJumpList();
    void restoreCursor();

    void saveSettings();

private:
    enum PostLaunchAction { OpenDownloadManager, OpenNewTab, ToggleFullScreen };

    void loadTheme(const QString &name);
    void translateApp();
    void restoreOtherWindows();
    void backupSavedSessions();

    QUrl userStyleSheet(const QString &filePath) const;

    CookieManager* m_cookiemanager;
    BrowsingLibrary* m_browsingLibrary;
    History* m_historymodel;
    QWebSettings* m_websettings;
    NetworkManager* m_networkmanager;
    CookieJar* m_cookiejar;
    RSSManager* m_rssmanager;
    PluginProxy* m_plugins;
    BookmarksModel* m_bookmarksModel;
    DownloadManager* m_downloadManager;
    AutoFill* m_autofill;
    QNetworkDiskCache* m_networkCache;
    DesktopNotificationsFactory* m_desktopNotifications;
    SearchEnginesManager* m_searchEnginesManager;
    RestoreManager* m_restoreManager;
    ProxyStyle* m_proxyStyle;
    HTML5PermissionsManager* m_html5permissions;
#ifdef USE_HUNSPELL
    Speller* m_speller;
#endif
    DatabaseWriter* m_dbWriter;
    UserAgentManager* m_uaManager;
    QList<QPointer<QupZilla> > m_mainWindows;

    QString m_activeProfil;
    QString m_activeLanguage;
    QString m_activeThemePath;

    bool m_isPrivateSession;
    bool m_isPortable;
    bool m_isClosing;
    bool m_isStateChanged;
    bool m_isRestoring;
    bool m_startingAfterCrash;

    bool m_databaseConnected;
    QList<PostLaunchAction> m_postLaunchActions;

#if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
    RegisterQAppAssociation* m_registerQAppAssociation;
#endif

#ifdef Q_OS_MAC
    MacMenuReceiver* m_macMenuReceiver;
    QMenu* m_macDockMenu;
#endif
};

#endif // MAINAPPLICATION_H

==> qupzilla_1.8.6~dfsg1.orig.tar.xz: qupzilla-1.8.6~dfsg1/src/lib/app/mainapplication.h <==
/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef MAINAPPLICATION_H
#define MAINAPPLICATION_H

#define mApp MainApplication::instance()

#include <QList>

#include "qtsingleapplication/qtsingleapplication.h"
#include "restoremanager.h"
#include "qzcommon.h"

class QMenu;
class QNetworkDiskCache;

class History;
class AutoFill;
class MainMenu;
class Bookmarks;
class CookieJar;
class AutoSaver;
class RSSManager;
class ProxyStyle;
class PluginProxy;
class BrowserWindow;
class NetworkManager;
class BrowsingLibrary;
class DownloadManager;
class UserAgentManager;
class SearchEnginesManager;
class HTML5PermissionsManager;
class RegisterQAppAssociation;
class DesktopNotificationsFactory;

class QUPZILLA_EXPORT MainApplication : public QtSingleApplication
{
    Q_OBJECT

public:
    explicit MainApplication(int &argc, char** argv);
    ~MainApplication();

    bool isClosing() const;
    bool isRestoring() const;
    bool isPrivate() const;
    bool isPortable() const;
    bool isStartingAfterCrash() const;

    int windowCount() const;
    QList<BrowserWindow*> windows() const;

    BrowserWindow* getWindow() const;
    BrowserWindow* createWindow(Qz::BrowserWindowType type, const QUrl &startUrl = QUrl());

    bool restoreSession(BrowserWindow* window, RestoreData restoreData);
    void destroyRestoreManager();
    void reloadSettings();

    ProxyStyle* proxyStyle() const;
    void setProxyStyle(ProxyStyle* style);

    // Name of current Qt style
    QString styleName() const;

    // TODO: Move translating into own class (LocaleManager ?)
    QString currentLanguageFile() const;
    QString currentLanguage() const;

    History* history();
    Bookmarks* bookmarks();

    AutoFill* autoFill();
    CookieJar* cookieJar();
    PluginProxy* plugins();
    QNetworkDiskCache* networkCache();
    BrowsingLibrary* browsingLibrary();

    RSSManager* rssManager();
    NetworkManager* networkManager();
    RestoreManager* restoreManager();
    DownloadManager* downloadManager();
    UserAgentManager* userAgentManager();
    SearchEnginesManager* searchEnginesManager();
    HTML5PermissionsManager* html5PermissionsManager();
    DesktopNotificationsFactory* desktopNotifications();

    static MainApplication* instance();

public slots:
    void addNewTab(const QUrl &url = QUrl());
    void startPrivateBrowsing(const QUrl &startUrl = QUrl());

    void reloadUserStyleSheet();
    void restoreOverrideCursor();

    void changeOcurred();
    void quitApplication();

signals:
    void settingsReloaded();

private slots:
    void postLaunch();

    void saveSession();
    void saveSettings();

    void messageReceived(const QString &message);
    void windowDestroyed(QObject* window);
    void onFocusChanged();

private:
    enum PostLaunchAction {
        OpenDownloadManager,
        OpenNewTab,
        ToggleFullScreen
    };

    void loadSettings();
    void loadTheme(const QString &name);

    void translateApp();
    void backupSavedSessions();
    void checkDefaultWebBrowser();

    QUrl userStyleSheet(const QString &filePath) const;

    bool m_isPrivate;
    bool m_isPortable;
    bool m_isClosing;
    bool m_isRestoring;
    bool m_isStartingAfterCrash;

    History* m_history;
    Bookmarks* m_bookmarks;

    AutoFill* m_autoFill;
    CookieJar* m_cookieJar;
    PluginProxy* m_plugins;
    QNetworkDiskCache* m_networkCache;
    BrowsingLibrary* m_browsingLibrary;

    RSSManager* m_rssManager;
    NetworkManager* m_networkManager;
    RestoreManager* m_restoreManager;
    DownloadManager* m_downloadManager;
    UserAgentManager* m_userAgentManager;
    SearchEnginesManager* m_searchEnginesManager;
    HTML5PermissionsManager* m_html5PermissionsManager;
    DesktopNotificationsFactory* m_desktopNotifications;

    AutoSaver* m_autoSaver;
    ProxyStyle* m_proxyStyle;

    QList<BrowserWindow*> m_windows;
    BrowserWindow* m_lastActiveWindow;

    QList<PostLaunchAction> m_postLaunchActions;

    QString m_languageFile;

#if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
public:
    RegisterQAppAssociation* associationManager();

private:
    RegisterQAppAssociation* m_registerQAppAssociation;
#endif

#ifdef Q_OS_MAC
public:
    bool event(QEvent* e);
#endif
};

#endif // MAINAPPLICATION_H
